capabilities – NETCONF Capabilities — ncclient 0.5.3 documentation

# `capabilities` – NETCONF Capabilities

`ncclient.capabilities.` `schemes`(url_uri)

  Given a URI that has a scheme query string (i.e. :url capability URI), will return a list of supported schemes.

class `ncclient.capabilities.` `Capabilities`(capabilities)

  Represents the set of capabilities available to a NETCONF client or server. It is initialized with a list of capability URI’s.

  Members

  `":cap" in caps`

    Check for the presence of capability. In addition to the URI, for capabilities of the form urn:ietf:params:netconf:capability:$name:$version their shorthand can be used as a key. For example, for urn:ietf:params:netconf:capability:candidate:1.0 the shorthand would be :candidate. If version is significant, use :candidate:1.0 as key.

  `iter(caps)`

    Return an iterator over the full URI’s of capabilities represented by this object.